==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_k8s_list_deleted/main.tf <==
/*
Пример использования
Получение списка удаленных кластеров
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером

terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}


provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_k8s_list_deleted" "k8s_list_deleted" {
  #фильтр по id кластера
  #опциональный параметр
  #тип - число
  #by_id = 100
 
  #фильтр по имени кластера
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по id балансировщика нагрузки
  #опциональный параметр
  #тип - число
  #lb_id = 100

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #bservice_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "output_k8s_list_deleted" {
  value = data.decort_k8s_list_deleted.k8s_list_deleted
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_k8s_list_deleted/main.tf <==
/*
Пример использования
Получение списка удаленных кластеров
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером

terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}


provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_k8s_list_deleted" "k8s_list_deleted" {
  #фильтр по id кластера
  #опциональный параметр
  #тип - число
  #by_id = 100
 
  #фильтр по имени кластера
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по id балансировщика нагрузки
  #опциональный параметр
  #тип - число
  #lb_id = 100

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #bservice_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "output_k8s_list_deleted" {
  value = data.decort_k8s_list_deleted.k8s_list_deleted
}
